<?php
/**
 * Initialize Plugin
 *
 * @package Easy Social Shares
 * @since 1.0.0
 */

if ( ! class_exists( 'Easy_Social_Shares' ) ) :

	/**
	 * Easy Social Shares
	 *
	 * @since 1.0.0
	 */
	class Easy_Social_Shares {

		/**
		 * Instance
		 *
		 * @access private
		 * @var object Class Instance.
		 * @since 1.0.0
		 */
		private static $instance;

		/**
		 * Initiator
		 *
		 * @since 1.0.0
		 * @return object initialized object of class.
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 * Constructor
		 */
		public function __construct() {
			add_shortcode( 'easy_social_shares', array( $this, 'shortcode_markup' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'script' ) );
		}

		/**
		 * Scripts
		 *
		 * @since 1.0.0
		 * @return void
		 */
		public function script() {
			wp_register_style( 'easy-social-shares', EASY_SOCIAL_SHARES_URI . 'assets/css/style.css', null, EASY_SOCIAL_SHARES_VER, 'all' );
			wp_enqueue_style( 'easy-social-shares' );
		}

		/**
		 * Shortcode Markup
		 *
		 * @param  array $atts Shortcode attributes.
		 * @since 1.0.0
		 * @return mixed
		 */
		public function shortcode_markup( $atts = array() ) {

			$atts = shortcode_atts(
				array(
					'id'     => get_the_ID(),
					'social' => 'facebook,twitter',
				),
				$atts
			);

			$social_accounts = explode( ',', $atts['social'] );

			// Empty social shares.
			if ( empty( $social_accounts ) ) {
				return '';
			}

			// Invalid/empty post ID.
			$post_id = isset( $atts['id'] ) ? absint( $atts['id'] ) : 0;
			if ( ! $post_id ) {
				return '';
			}
			$post_share_url   = get_permalink( $post_id );
			$post_title       = get_the_title( $post_id );
			$post_share_title = html_entity_decode( wp_kses( $post_title, null ) );
			$args             = array(
				'url'   => $post_share_url,
				'title' => $post_share_title,
			);

			ob_start();
			?>
			<div id="easy-social-shares">
				<ul>
					<?php
					foreach ( $social_accounts as $key => $social_account ) {
						switch ( $social_account ) {
							case 'facebook':
									$this->facebook_markup( $args );
								break;
							case 'twitter':
									$this->twitter_markup( $args );
								break;
						}
					}
					?>
				</ul>
			</div>
			<?php
			return ob_get_clean();
		}

		/**
		 * Twitter Button Markup
		 *
		 * @since 1.0.0
		 * @param  array $args Shortcode attributes.
		 * @return void
		 */
		public function twitter_markup( $args = array() ) {
			$twitter_url = add_query_arg(
				array(
					'url'      => rawurlencode( $args['url'] ),
					'text'     => rawurlencode( $args['title'] ),
					'via'      => '',
					'hashtags' => '',
				),
				'https://twitter.com/intent/tweet'
			);
			/* translators: %s is post title */
			$share_title = sprintf( __( 'Share: %s ', 'easy-social-shares' ), $args['title'] );
			?>
			<li>
				<a href="<?php echo esc_url_raw( $twitter_url ); ?>" title="<?php echo esc_html( $share_title ); ?>">
					<img src="<?php echo esc_url_raw( EASY_SOCIAL_SHARES_URI . 'assets/images/twitter.svg' ); ?>" title="<?php echo esc_html( $share_title ); ?>" alt="<?php echo esc_html( $share_title ); ?>" />
				</a>
			</li>
			<?php
		}

		/**
		 * Facebook Button Markup
		 *
		 * @since 1.0.0
		 * @param  array $args Shortcode attributes.
		 * @return void
		 */
		public function facebook_markup( $args = array() ) {
			$facebook_url = add_query_arg(
				array(
					'u' => rawurlencode( $args['url'] ),
					't' => rawurlencode( $args['title'] ),
				),
				'https://www.facebook.com/sharer/sharer.php'
			);
			/* translators: %s is post title */
			$share_title = sprintf( __( 'Share: %s ', 'easy-social-shares' ), $args['title'] );
			?>
			<li>
				<a href="<?php echo esc_url_raw( $facebook_url ); ?>" title="<?php echo esc_html( $share_title ); ?>">
					<img src="<?php echo esc_url_raw( EASY_SOCIAL_SHARES_URI . 'assets/images/facebook.svg' ); ?>" title="<?php echo esc_html( $share_title ); ?>" alt="<?php echo esc_html( $share_title ); ?>" />
				</a>
			</li>
			<?php
		}
	}

	/**
	 * Kicking this off by calling 'get_instance()' method
	 */
	Easy_Social_Shares::get_instance();

endif;
